[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- mysql: MySQL 5 interface.

- mysql.connection: Connection object used to communicate with the MySQL server.
- mysql.constants: Subpackage of constants used in the MySQL library.

- mysql.constants.client_flags: Flags used for connecting to the server.
- mysql.constants.field_flags: Flags used in the `flags` attribute of the mysql.result.Field object.
- mysql.constants.field_types: Identifiers of different field types.

- mysql.conversion: Data type conversion code for the mysql.connection.Connection.execute API.

- mysql.conversion.input: Input Conversion converts Python data types to be made appropriate for MySQL parameters.
- mysql.conversion.output: Output Conversion converts values from MySQL (which are always strings) to Python data types.

- mysql.exceptions: All MySQL exceptions.

- mysql.exceptions.base: Base exception classes.
- mysql.exceptions.client: Exceptions from the MySQL client API.
- mysql.exceptions.internal: Internal errors from the MySQL Python code.
- mysql.exceptions.map: Mapping of MySQL internal error codes to exception objects.
- mysql.exceptions.server: Exceptions from the MySQL server.

- mysql.result: Result object for SQL queries.
- mysql.stmt: MySQL Statement API.

- mysql.stmt.bind_in: MySQL Statement Input Binding.
- mysql.stmt.bind_out: MySQL Statement Output Binding.
- mysql.stmt.stmt: MySQL Statement object.

- mysql.util: Subpackage of internal utility modules.

- mysql.util._c_only: Internal module of C helper functions.
- mysql.util.misc: Miscellaneous utility functions.
- mysql.util.string: Internal string manipulation routines.